#!/usr/bin/env python

from distutils.core import setup

setup(name='bigpanda',
      version='1.5.0',
      description='Python module for integration with BigPanda',
      author='BigPanda',
      author_email='support@bigpanda.io',
      url='bigpanda.io',
      packages=['bigpanda']
)
